Examples
########

This section provides examples that show how the Ansys Sphinx Theme renders different Sphinx extensions and documentation components.

Sphinx extensions
=================

These examples show how the Ansys Sphinx Theme renders different Sphinx extensions.

.. grid:: 1 2 3 3
   :gutter: 1 2 3 3
   :padding: 1 2 3 3

   .. grid-item-card:: :octicon:`note` Sphinx design
      :link: sphinx-design
      :link-type: ref

      Examples of how the Sphinx design is rendered.

   .. grid-item-card:: :octicon:`book` Jupyter notebook - nbsphinx
      :link: nbsphinx
      :link-type: ref

      Examples of how notebooks are rendered.

   .. grid-item-card:: :octicon:`link-external` Sphinx gallery
      :link: examples/gallery-examples/index
      :link-type: doc

      Examples of how the Sphinx gallery is rendered.

   .. grid-item-card:: :octicon:`bookmark` Sphinx autoapi
      :link: sphinx-autoapi
      :link-type: ref

      Examples of how Sphinx AutoAPI documentation is rendered.

Documentation components
========================

These examples show how the Ansys Sphinx Theme renders different documentation components.


.. grid:: 2
   :gutter: 2 2 3 4
   :padding: 2 2 3 4

   .. grid-item-card:: :octicon:`table` Tables
      :link: table
      :link-type: ref

      Examples of tables with JavaScript and RST rendered using the `ansys-sphinx-theme`.

   .. grid-item-card:: :octicon:`info` Admonitions
      :link: admonitions
      :link-type: ref

      Examples of how admonitions are rendered.



.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Sphinx extensions

   examples/sphinx-design
   examples/nbsphinx
   examples/gallery-examples/index
   examples/sphinx-autoapi


.. toctree::
   :hidden:
   :maxdepth: 2
   :caption: Documentation components

   examples/table
   examples/admonitions

